Index: src/ast/scopes.cc |
diff --git a/src/ast/scopes.cc b/src/ast/scopes.cc |
index d45b02091cd805d1b0e5ec8fad07f651cac2ca7b..e4ac5d5b54c372e7b57ff3384c42a94bd5bad63e 100644 |
--- a/src/ast/scopes.cc |
+++ b/src/ast/scopes.cc |
@@ -1045,12 +1045,14 @@ void DeclarationScope::AllocateVariables(ParseInfo* info, AnalyzeMode mode) { |
AllocateScopeInfosRecursively(info->isolate(), mode, outer_scope); |
} |
-bool Scope::AllowsLazyParsing() const { |
- // If we are inside a block scope, we must parse eagerly to find out how |
- // to allocate variables on the block scope. At this point, declarations may |
- // not have yet been parsed. |
+bool Scope::AllowsLazyParsingWithoutUnresolvedVariables() const { |
+ // If we are inside a block scope, we must find unresolved variables in the |
+ // inner scopes to find out how to allocate variables on the block scope. At |
+ // this point, declarations may not have yet been parsed. |
for (const Scope* s = this; s != nullptr; s = s->outer_scope_) { |
if (s->is_block_scope()) return false; |
+ // TODO(marja): Refactor parsing modes: also add s->is_function_scope() |
+ // here. |
} |
return true; |
} |